/**********************************************
 * 文件名  ：FS2000.c
 * 描述    ：FS2000模块         
 * 用户	   ：袁亨
************************************************/
#include "main.h"

//功能：读传感器流量
//输出：传感器流量(SCCM)
float ReadLiquid(void)
{
	float REG_data; 
	if(!I2C_Start())
		return FALSE;	
  I2C_SendByte( (FS2000_Address<<1)+1 );
  if(!I2C_WaitAck())
		return FALSE;
	REG_data = ( I2C_RadeByte()<<8  );
	I2C_Ack();
	REG_data = REG_data + I2C_RadeByte();
	I2C_NoAck();
	I2C_Stop();
	return 	REG_data /10;	
}
